==> ejc-purchasingmanagement-impl-3.0.0-20220424.052451-26-sources.jar: com/ejianc/business/purchasingmanagement/service/impl/MaterialplanServiceImpl.java <==
package com.ejianc.business.purchasingmanagement.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.ejianc.business.purchasingmanagement.bean.PurchaseContractEntity;
import com.ejianc.business.purchasingmanagement.bean.PurchasecontractdetailEntity;
import com.ejianc.business.purchasingmanagement.bean.PurchasetransportationEntity;
import com.ejianc.business.purchasingmanagement.service.IPurchasecontractdetailService;
import com.ejianc.business.purchasingmanagement.service.IPurchasetransportationService;
import com.ejianc.business.purchasingmanagement.vo.MaterialplanVO;
import com.ejianc.business.purchasingmanagement.vo.PurchasetransportationVO;
import com.ejianc.foundation.orgcenter.api.IOrgApi;
import com.ejianc.foundation.support.api.IBillCodeApi;
import com.ejianc.foundation.support.vo.BillCodeParam;
import com.ejianc.framework.core.context.InvocationInfoProxy;
import com.ejianc.framework.core.exception.BusinessException;
import com.ejianc.framework.core.kit.mapper.BeanMapper;
import com.ejianc.framework.core.response.CommonResponse;
import com.ejianc.framework.core.response.Parameter;
import com.ejianc.framework.core.response.QueryParam;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ejianc.framework.skeleton.template.BaseServiceImpl;

import com.ejianc.business.purchasingmanagement.mapper.MaterialplanMapper;
import com.ejianc.business.purchasingmanagement.bean.MaterialplanEntity;
import com.ejianc.business.purchasingmanagement.service.IMaterialplanService;

/**
 * 定料计划
 * 
 * @author generator
 * 
 */
@Service("materialplanService")
public class MaterialplanServiceImpl extends BaseServiceImpl<MaterialplanMapper, MaterialplanEntity> implements IMaterialplanService{

    @Autowired
    private IBillCodeApi billCodeApi;
    @Autowired
    private IOrgApi iOrgApi;

    private static final String BILL_CODE = "Invoice_Open_Apply_Code";//此处需要根据实际修改

    @Autowired
    private IMaterialplanService service;
    @Autowired
    private IPurchasetransportationService purchasetransportationService;

    @Autowired
    private IPurchasecontractdetailService purchasecontractdetailService;


    @Override
    public CommonResponse<MaterialplanVO> saveChange(MaterialplanVO saveChangeVO) {
        //定料计划生成单据
        MaterialplanEntity entity = BeanMapper.map(saveChangeVO, MaterialplanEntity.class);
        if(entity.getId() == null || entity.getId() == 0){
            BillCodeParam billCodeParam = BillCodeParam.build(BILL_CODE, InvocationInfoProxy.getTenantid(),saveChangeVO);
            CommonResponse<String> billCode = billCodeApi.generateBillCode(billCodeParam);
            if(billCode.isSuccess()) {
                //  entity.setCode(billCode.getData());//此处需要根据实际修改 删除本行或者下一行
                entity.setBillCode(billCode.getData());//此处需要根据实际修改 删除本行或者上一行
            }else{
                throw new BusinessException("网络异常， 编码生成失败， 请稍后再试");
            }
        }

        PurchasecontractdetailEntity purchasecontractdetailEntity = purchasecontractdetailService.selectById(entity.getPurchasecontractdetailId());
        entity.setPrice(purchasecontractdetailEntity.getPrice());//单价
        entity.setMaterialTax(purchasecontractdetailEntity.getMaterialTax());//材料税率
        entity.setFreightRate(purchasecontractdetailEntity.getFreightRate());// 运费税率


        service.saveOrUpdate(entity, false);
        MaterialplanVO vo = BeanMapper.map(entity, MaterialplanVO.class);

        QueryWrapper<PurchasetransportationEntity> queryWrapper=new QueryWrapper();
        queryWrapper.eq("materialplan_id",vo.getId());
        queryWrapper.eq("dr","0");
        PurchasetransportationEntity page = purchasetransportationService.getOne(queryWrapper);


        if(page == null ){
            //根据定料计划生成采购运输信息单
            PurchasetransportationVO purchasetransportationVO  = new PurchasetransportationVO();
            purchasetransportationVO.setMaterialplanId(vo.getId());//定料计划
            purchasetransportationVO.setSupplierinfoId(vo.getSupplierinfoId());//供应商id
            purchasetransportationVO.setSupplierinfoName(vo.getSupplierinfoName());//供应商名称
            purchasetransportationVO.setMaterialId(vo.getMaterialId());//原材料ID
            purchasetransportationVO.setMaterialName(vo.getMaterialName());//原材料
            purchasetransportationVO.setRequiredQuantity(vo.getQuantity());//需求数量
            purchasetransportationVO.setReceivingaddressId(vo.getMddId());//收货地址ID
            purchasetransportationVO.setReceivingAddress(vo.getMddName());//收货地址
            purchasetransportationVO.setOrgId(vo.getOrgId());//组织ID
            purchasetransportationVO.setOrgName(vo.getOrgName());//组织名称
            purchasetransportationVO.setShippersId(purchasecontractdetailEntity.getShippersId());//运输商id
            purchasetransportationVO.setShippersName(purchasecontractdetailEntity.getShippersName());//运输商
            BillCodeParam billCodeParam = BillCodeParam.build(BILL_CODE,InvocationInfoProxy.getTenantid(),purchasetransportationVO);
            CommonResponse<String> billCode = billCodeApi.generateBillCode(billCodeParam);
            if(billCode.isSuccess()) {

                PurchasetransportationEntity entity1 = BeanMapper.map(purchasetransportationVO, PurchasetransportationEntity.class);
                entity1.setBillCode(billCode.getData());//此处需要根据实际修改 删除本行或者上一行
                purchasetransportationService.saveOrUpdate(entity1, false);
            }else{
                throw new BusinessException("网络异常， 编码生成失败， 请稍后再试");
            }

        }

        return CommonResponse.success("保存或修改单据成功！",vo);
    }
}

==> ejc-purchasingmanagement-impl-3.0.0-20220511.150614-65-sources.jar: com/ejianc/business/purchasingmanagement/service/impl/MaterialplanServiceImpl.java <==
package com.ejianc.business.purchasingmanagement.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.ejianc.business.purchasingmanagement.bean.PurchaseContractEntity;
import com.ejianc.business.purchasingmanagement.bean.PurchasecontractdetailEntity;
import com.ejianc.business.purchasingmanagement.bean.PurchasetransportationEntity;
import com.ejianc.business.purchasingmanagement.service.IPurchasecontractdetailService;
import com.ejianc.business.purchasingmanagement.service.IPurchasetransportationService;
import com.ejianc.business.purchasingmanagement.vo.MaterialplanVO;
import com.ejianc.business.purchasingmanagement.vo.PurchasetransportationVO;
import com.ejianc.foundation.orgcenter.api.IOrgApi;
import com.ejianc.foundation.support.api.IBillCodeApi;
import com.ejianc.foundation.support.vo.BillCodeParam;
import com.ejianc.framework.core.context.InvocationInfoProxy;
import com.ejianc.framework.core.exception.BusinessException;
import com.ejianc.framework.core.kit.mapper.BeanMapper;
import com.ejianc.framework.core.response.CommonResponse;
import com.ejianc.framework.core.response.Parameter;
import com.ejianc.framework.core.response.QueryParam;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ejianc.framework.skeleton.template.BaseServiceImpl;

import com.ejianc.business.purchasingmanagement.mapper.MaterialplanMapper;
import com.ejianc.business.purchasingmanagement.bean.MaterialplanEntity;
import com.ejianc.business.purchasingmanagement.service.IMaterialplanService;

/**
 * 定料计划
 * 
 * @author generator
 * 
 */
@Service("materialplanService")
public class MaterialplanServiceImpl extends BaseServiceImpl<MaterialplanMapper, MaterialplanEntity> implements IMaterialplanService{

    @Autowired
    private IBillCodeApi billCodeApi;
    @Autowired
    private IOrgApi iOrgApi;

    private static final String BILL_CODE = "Invoice_Open_Apply_Code";//此处需要根据实际修改

    @Autowired
    private IMaterialplanService service;
    @Autowired
    private IPurchasetransportationService purchasetransportationService;

    @Autowired
    private IPurchasecontractdetailService purchasecontractdetailService;


    @Override
    public CommonResponse<MaterialplanVO> saveChange(MaterialplanVO saveChangeVO) {
        //定料计划生成单据
        MaterialplanEntity entity = BeanMapper.map(saveChangeVO, MaterialplanEntity.class);
        if(entity.getId() == null || entity.getId() == 0){
            BillCodeParam billCodeParam = BillCodeParam.build(BILL_CODE, InvocationInfoProxy.getTenantid(),saveChangeVO);
            CommonResponse<String> billCode = billCodeApi.generateBillCode(billCodeParam);
            if(billCode.isSuccess()) {
                //  entity.setCode(billCode.getData());//此处需要根据实际修改 删除本行或者下一行
                entity.setBillCode(billCode.getData());//此处需要根据实际修改 删除本行或者上一行
            }else{
                throw new BusinessException("网络异常， 编码生成失败， 请稍后再试");
            }
        }

        PurchasecontractdetailEntity purchasecontractdetailEntity = purchasecontractdetailService.selectById(entity.getPurchasecontractdetailId());
        entity.setPrice(purchasecontractdetailEntity.getPrice());//单价
        entity.setMaterialTax(purchasecontractdetailEntity.getMaterialTax());//材料税率
        entity.setFreightRate(purchasecontractdetailEntity.getFreightRate());// 运费税率


        service.saveOrUpdate(entity, false);
        MaterialplanVO vo = BeanMapper.map(entity, MaterialplanVO.class);

        QueryWrapper<PurchasetransportationEntity> queryWrapper=new QueryWrapper();
        queryWrapper.eq("materialplan_id",vo.getId());
        queryWrapper.eq("dr","0");
        PurchasetransportationEntity page = purchasetransportationService.getOne(queryWrapper);
        if(page == null ){
            //根据定料计划生成采购运输信息单
            PurchasetransportationVO purchasetransportationVO  = new PurchasetransportationVO();
            purchasetransportationVO.setMaterialplanId(vo.getId());//定料计划
            purchasetransportationVO.setSupplierinfoId(vo.getSupplierinfoId());//供应商id
            purchasetransportationVO.setSupplierinfoName(vo.getSupplierinfoName());//供应商名称
            purchasetransportationVO.setMaterialId(vo.getMaterialId());//原材料ID
            purchasetransportationVO.setMaterialName(vo.getMaterialName());//原材料
            purchasetransportationVO.setRequiredQuantity(vo.getQuantity());//需求数量
            purchasetransportationVO.setReceivingaddressId(vo.getMddId());//收货地址ID
            purchasetransportationVO.setReceivingAddress(vo.getMddName());//收货地址
            purchasetransportationVO.setOrgId(vo.getOrgId());//组织ID
            purchasetransportationVO.setOrgName(vo.getOrgName());//组织名称
            purchasetransportationVO.setShippersId(purchasecontractdetailEntity.getShippersId());//运输商id
            purchasetransportationVO.setShippersName(purchasecontractdetailEntity.getShippersName());//运输商
            purchasetransportationVO.setUnitPrice(purchasecontractdetailEntity.getSjyfPrice());//运费
            purchasetransportationVO.setDistance(purchasecontractdetailEntity.getDistance());//运距
            purchasetransportationVO.setStartingTime(vo.getStarDate());
            purchasetransportationVO.setEndTime(vo.getEndDate());

            BillCodeParam billCodeParam = BillCodeParam.build(BILL_CODE,InvocationInfoProxy.getTenantid(),purchasetransportationVO);
            CommonResponse<String> billCode = billCodeApi.generateBillCode(billCodeParam);
            if(billCode.isSuccess()) {

                PurchasetransportationEntity entity1 = BeanMapper.map(purchasetransportationVO, PurchasetransportationEntity.class);
                entity1.setBillCode(billCode.getData());//此处需要根据实际修改 删除本行或者上一行
                purchasetransportationService.saveOrUpdate(entity1, false);
            }else{
                throw new BusinessException("网络异常， 编码生成失败， 请稍后再试");
            }

        }

        return CommonResponse.success("保存或修改单据成功！",vo);
    }
}
